@@ -43,6 +43,7 @@ import glob
 import re
 import logging
 import time
+from datetime import datetime
 import xml.etree.ElementTree as ET
 from functools import wraps
 sns.set(color_codes=True)
@@ -875,6 +876,51 @@ class PipelineEndpointLauncher:
         print("pipeline_endpoint_by_name.endpoint : ", rest_endpoint)
         _ = requests.post(rest_endpoint, headers=auth_header, json=json_data)
 
+class SampledDataDispatcher:
+    def __init__(self, config):
+        self.config = config
+    
+    def dispatch(self, sampled_folder, 
+                            sampled_data, 
+                                    number_files,
+                                        sampled_data_builder,
+                                                    blob_manager):
+
+        assert(isinstance(sampled_data, list) == True, "sampled_data must be a list")
+        for item_to_check in sampled_data:
+            assert(isinstance(item_to_check, list) == True, "item in list sampled_data must be a list")
+            assert(len(item_to_check) == 5, "item in list sampled_data must  must have 5 elements")
+        assert(number_files <= len(sampled_data), "number_files must be less than " + len(sampled_data))
+
+        splitted_data = np.array_split(sampled_data, number_files)
+        for index, data in enumerate(splitted_data):
+            samped_json_data = sampled_data_builder.build(data)
+            
+            part_path = "part_{0}".format(index)
+            sampled_item_folder = os.path.join(sampled_folder, part_path)
+            os.makedirs(sampled_item_folder, exist_ok=True)
+            sampling_file_path = os.path.join(sampled_item_folder, "sampled_data.json")
+            #create sampled_data json file
+            with open(sampling_file_path, "w") as write_file:
+                json.dump(samped_json_data, write_file)
+
+            #create sampled_meta_data json file
+            meta_json_data = {}
+            meta_json_data["userid"] = ""
+            meta_json_data["creationDate"] = datetime.now.strftime("%d/%m/%Y %H:%M:%S")
+            meta_json_data["modificationDate"] = ""
+            meta_json_data["status"] = "created" #progressing, completed
+            meta_json_data["isLocked"] = False
+            sampling_meta_file_path = os.path.join(sampled_item_folder, "sampled_meta_data.json")
+            with open(sampling_meta_file_path, "w") as write_file:
+                json.dump(meta_json_data, write_file)
+
+            remote_sampling_file_path = "{0}/{1}/cleandata/sampled_data/current/{2}".format(self.config.CONTAINER_NAME, self.config.ENV_DIR, part_path)
+            blob_manager.upload(remote_sampling_file_path, sampling_file_path, overwrite_v=True)
+
+            remote_sampling_meta_file_path = "{0}/{1}/cleandata/sampled_data/current/{2}".format(self.config.CONTAINER_NAME, self.config.ENV_DIR, part_path)
+            blob_manager.upload(remote_sampling_meta_file_path, sampling_meta_file_path, overwrite_v=True)
+
 class BlobStorageManagerMoq:
     def __init__(self, connection_string):
         self.connection_string = connection_string
